import { ChangeDetectionStrategy, Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NzCarouselModule } from 'ng-zorro-antd/carousel';
import { ProgressBarComponent } from '../../shared/ui/progress-bar/progress-bar.component';
import { AuthorListComponent } from '../../shared/ui/author-list/author-list.component';
import { ToggleComponent } from '../../shared/ui/toggle/toggle.component';
import { CardComponent } from '../../shared/ui/card/card.component';
import { ModalComponent } from '../../shared/ui/modal/modal.component';
import { DIComparisonComponent } from '../../shared/ui/di-comparison/di-comparison.component';
import { ProductListComponent } from '../../shared/ui/product-list/product-list.component';
import { CartViewComponent } from '../../shared/ui/cart-view/cart-view.component';
import { FormsModule } from '@angular/forms';

@Component({
  selector: 'meu-home',
  standalone: true,
  imports: [
    CommonModule, 
    NzCarouselModule, 
    ProgressBarComponent, 
    AuthorListComponent, 
    ToggleComponent, 
    CardComponent, 
    ModalComponent,
    DIComparisonComponent,
    ProductListComponent,
    CartViewComponent,
    FormsModule
  ],
  templateUrl: './home.component.html',
  styleUrl: './home.component.scss',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class HomeComponent {
  uploadProgress = 65; 
  videoProgress = 80;
  downloadProgress = 30;

  // Two-way binding properties for demo
  toggleState1 = false;
  toggleState2 = true;
  toggleState3 = false;
  userName = 'Truc Thanh';

  // Content Projection demo properties
  isModalOpen = false;
  surveyAnswers = {
    question1: false,
    question2: false,
    question3: false
  };

  // Day 14: ng-template demo properties
  userAge18 = false;
  itemCounter = 3;
  Math = Math; // Expose Math object to template

  // Action log for button demo
  actionLog: Array<{time: string, message: string}> = [];

  // Custom card data
  customCardData = {
    title: 'Advanced ng-template Demo',
    description: 'Đây là ví dụ về cách sử dụng ng-template để tạo ra các component có thể customize cao.',
    tags: ['angular', 'ng-template', 'reusable', 'flexible']
  };

  // Card actions
  cardActions = [
    {
      label: 'Like',
      icon: '👍',
      className: 'tw-bg-blue-500 hover:tw-bg-blue-600 tw-text-white',
      handler: () => this.addActionLog('👍 Card liked!')
    },
    {
      label: 'Share',
      icon: '📤',
      className: 'tw-bg-green-500 hover:tw-bg-green-600 tw-text-white',
      handler: () => this.addActionLog('📤 Card shared!')
    },
    {
      label: 'Save',
      icon: '💾',
      className: 'tw-bg-purple-500 hover:tw-bg-purple-600 tw-text-white',
      handler: () => this.addActionLog('💾 Card saved!')
    }
  ];

  getCurrentTime(): string {
    return new Date().toLocaleTimeString();
  }

  // Methods for Content Projection demo
  openModal(): void {
    this.isModalOpen = true;
  }

  closeModal(): void {
    this.isModalOpen = false;
  }

  onSave(): void {
    console.log('Survey answers:', this.surveyAnswers);
    alert('Survey saved! Check console for details.');
    this.closeModal();
  }

  resetSurvey(): void {
    this.surveyAnswers = {
      question1: false,
      question2: false,
      question3: false
    };
  }

  // Button callback methods
  saveDocument = () => {
    this.addActionLog('💾 Document saved successfully!');
  };

  deleteFile = () => {
    this.addActionLog('🗑️ File deleted permanently!');
  };

  completeTask = () => {
    this.addActionLog('✅ Task marked as completed!');
  };

  cancelProcess = () => {
    this.addActionLog('⚠️ Process cancelled by user!');
  };

  addActionLog(message: string): void {
    const time = new Date().toLocaleTimeString();
    this.actionLog.unshift({ time, message });
    // Keep only last 10 actions
    if (this.actionLog.length > 10) {
      this.actionLog = this.actionLog.slice(0, 10);
    }
  }

  clearActionLog(): void {
    this.actionLog = [];
  }

  trackByIndex(index: number): number {
    return index;
  }
}
