import { Injectable } from '@angular/core';
import { Observable, of, delay } from 'rxjs';
import { ProductModel } from '../interface/product.interface';
import { MOCK_PRODUCTS } from '../const/products.const';

/**
 * ProductService - Product management
 */
@Injectable({
  providedIn: 'root'
})
export class ProductService {
  
  constructor() {
    console.log('🛍️ ProductService created');
  }

  getAllProducts(): Observable<ProductModel[]> {
    console.log('📦 Loading products...');
    return of(MOCK_PRODUCTS).pipe(
      delay(100) // Quick loading
    );
  }

  /**
   * Lấy sản phẩm theo ID
   */
  getProductById(id: number): Observable<ProductModel | undefined> {
    const product = MOCK_PRODUCTS.find(p => p.id === id);
    return of(product).pipe(delay(50));
  }

  /**
   * Tìm kiếm sản phẩm theo tên
   */
  searchProducts(query: string): Observable<ProductModel[]> {
    const filteredProducts = MOCK_PRODUCTS.filter(product =>
      product.name.toLowerCase().includes(query.toLowerCase()) ||
      product.description?.toLowerCase().includes(query.toLowerCase())
    );
    return of(filteredProducts).pipe(delay(50));
  }

  getProductsByCategory(category: string): Observable<ProductModel[]> {
    return of(MOCK_PRODUCTS).pipe(delay(50));
  }
}
