import { Component, Input, Output, EventEmitter, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Author } from '../../data-access/interface/author.interface';

@Component({
  selector: 'app-author-detail',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div *ngIf="author" class="tw-border tw-border-gray-300 tw-rounded-lg tw-p-4 tw-mb-3 tw-bg-white tw-shadow-sm hover:tw-shadow-md tw-transition-shadow">
      <div class="tw-flex tw-justify-between tw-items-center">
        <div class="tw-flex-1">
          <div class="tw-flex tw-items-center tw-space-x-2 tw-mb-2">
            <strong class="tw-text-lg tw-text-gray-800">{{ author.firstName }} {{ author.lastName }}</strong>
            <span class="tw-text-xs tw-bg-gray-100 tw-px-2 tw-py-1 tw-rounded tw-font-mono">ID: {{ author.id }}</span>
          </div>
          <p class="tw-text-sm tw-text-gray-600 tw-mb-1">
            📧 {{ author.email }}
          </p>
          <div class="tw-flex tw-space-x-4 tw-text-xs tw-text-gray-500">
            <span>👤 {{ author.gender }}</span>
            <span>🌐 {{ author.ipAddress }}</span>
          </div>
        </div>
        <button 
          (click)="handleDelete()" 
          class="tw-bg-red-500 hover:tw-bg-red-600 tw-text-white tw-font-bold tw-py-2 tw-px-3 tw-rounded tw-transition-colors tw-ml-4"
          title="Delete Author"
        >
          🗑️
        </button>
      </div>
    </div>
  `,
  styles: []
})
export class AuthorDetailComponent implements OnInit {
  @Input() author!: Author;
  @Output() deleteAuthor = new EventEmitter<Author>();

  constructor() {}

  ngOnInit(): void {
    console.log('AuthorDetailComponent initialized for:', this.author?.firstName, this.author?.lastName);
  }

  handleDelete(): void {
    console.log('Delete button clicked for author:', this.author);
    console.log('Emitting deleteAuthor event...');
    this.deleteAuthor.emit(this.author);
  }
}
