import { Component, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { CartService } from '../../../shared/data-access/service/cart.service';

/**
 * DI Demo Component
 */
@Component({
  selector: 'app-di-comparison',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './di-comparison.component.html',
  styleUrls: ['./di-comparison.component.scss']
})
export class DIComparisonComponent implements OnInit {

  constructor(private cartService: CartService) {
    console.log('🎯 DIComparisonComponent: CartService injected');
  }

  ngOnInit(): void {
    this.demonstrateDI();
  }

  private demonstrateDI(): void {
    console.log('🔍 Demonstrating DI concepts...');
    console.log('📦 Current CartService instance:', this.cartService);
    console.log('🔢 Cart total:', this.cartService.calculateTotal());
  }

  demoServiceMethods(): void {
    console.log('✅ Demo: Using injected service');
    const total = this.cartService.calculateTotal();
    const itemCount = this.cartService.getTotalItems();
    
    console.log('💰 Total from injected service:', total);
    console.log('📦 Item count from injected service:', itemCount);
  }

  demoManualInstantiation(): void {
    console.log('❌ Demo: Manual Instantiation (Not Recommended)');
    const manualService = new CartService();
    console.log('⚠️ Manual instance:', manualService);
    console.log('💸 Problems: Tight coupling, không share state, khó test');
  }

  demoProviderOverride(): void {
    console.log('🔄 Demo: Provider Override Concept');
    console.log('📝 Current service:', this.cartService.constructor.name);
    console.log('🎯 In real app: Can override with different implementations');
    console.log('   - MockCartService for testing');
    console.log('   - PremiumCartService for premium users');
    console.log('   - OfflineCartService for offline mode');
  }

  demoSingleton(): void {
    console.log('🔗 Demo: Singleton Pattern in DI');
    console.log('🎯 CartService instance:', this.cartService);
    console.log('🔄 Same instance across components due to providedIn: "root"');
    console.log('💡 Benefits: Shared state, better performance, less memory');
  }
}
