import { Component, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-modal',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div 
      class="tw-fixed tw-inset-0 tw-bg-black tw-bg-opacity-50 tw-flex tw-items-center tw-justify-center tw-z-50" 
      *ngIf="isOpen" 
      (click)="closeModal()">
      <div 
        class="tw-bg-white tw-rounded-lg tw-max-w-lg tw-w-full tw-mx-4 tw-max-h-screen tw-overflow-hidden tw-shadow-xl" 
        (click)="$event.stopPropagation()">
        
        <!-- Modal Header -->
        <div class="tw-px-6 tw-py-4 tw-border-b tw-border-gray-200 tw-flex tw-justify-between tw-items-center tw-bg-gray-50">
          <ng-content select="modal-header"></ng-content>
          <button 
            class="tw-bg-transparent tw-border-none tw-text-2xl tw-cursor-pointer tw-text-gray-500 hover:tw-text-gray-700 tw-w-8 tw-h-8 tw-flex tw-items-center tw-justify-center tw-rounded hover:tw-bg-gray-200 tw-transition-colors" 
            (click)="closeModal()" 
            type="button">
            ×
          </button>
        </div>
        
        <!-- Modal Body -->
        <div class="tw-p-6 tw-max-h-96 tw-overflow-y-auto">
          <ng-content select="modal-body"></ng-content>
        </div>
        
        <!-- Modal Footer -->
        <div class="tw-px-6 tw-py-4 tw-border-t tw-border-gray-200 tw-flex tw-justify-end tw-gap-2 tw-bg-gray-50">
          <ng-content select="modal-footer"></ng-content>
        </div>
      </div>
    </div>
  `,
  styles: []
})
export class ModalComponent {
  @Input() isOpen = false;
  @Output() closeEvent = new EventEmitter<void>();

  closeModal(): void {
    this.closeEvent.emit();
  }
}
