import { Component, Input, Output, EventEmitter, OnInit } from '@angular/core';
import { CommonModule } from '@angular/common';

@Component({
  selector: 'app-toggle',
  standalone: true,
  imports: [CommonModule],
  template: `
    <div
      class="toggle-wrapper"
      [class.checked]="checked"
      tabindex="0"
      (click)="toggle()"
      (keydown.enter)="toggle()"
      (keydown.space)="toggle()"
    >
      <div class="toggle"></div>
    </div>
    <div class="toggle-label">
      <ng-content></ng-content>
    </div>
  `,
  styles: [`
    .toggle-wrapper {
      display: flex;
      align-items: center;
      justify-content: center;
      cursor: pointer;
      transition: all 0.2s;
      width: 100px;
      height: 100px;
      border-radius: 50%;
      background-color: #fe4551;
      box-shadow: 0 20px 20px 0 rgba(254, 69, 81, 0.3);
      outline: none;
    }

    .toggle-wrapper:active {
      width: 95px;
      height: 95px;
      box-shadow: 0 15px 15px 0 rgba(254, 69, 81, 0.5);
    }

    .toggle-wrapper:focus {
      outline: 2px solid #007acc;
      outline-offset: 2px;
    }

    .toggle {
      transition: all 0.2s ease-in-out;
      height: 20px;
      width: 20px;
      background-color: transparent;
      border: 10px solid #fff;
      border-radius: 50%;
      cursor: pointer;
    }

    .toggle-wrapper.checked {
      background-color: #48e98a;
      box-shadow: 0 20px 20px 0 rgba(72, 233, 138, 0.3);
    }

    .toggle-wrapper.checked:active {
      box-shadow: 0 15px 15px 0 rgba(72, 233, 138, 0.5);
    }

    .toggle-wrapper.checked .toggle {
      width: 0;
      height: 17px;
      background-color: #fff;
      border-color: transparent;
      border-radius: 30px;
    }
  `]
})
export class ToggleComponent implements OnInit {
  // Input property - nhận giá trị từ parent
  @Input() checked = false;
  
  // Output property với suffix "Change" - gửi event về parent
  @Output() checkedChange = new EventEmitter<boolean>();

  constructor() {}

  ngOnInit(): void {
    console.log('Toggle component initialized with checked:', this.checked);
  }

  toggle(): void {
    console.log('Toggle clicked! Current state:', this.checked);
    
    // Thay đổi state
    this.checked = !this.checked;
    
    // Emit event về parent component (quan trọng cho two-way binding!)
    this.checkedChange.emit(this.checked);
    
    console.log('New state:', this.checked, 'Event emitted!');
  }
}
